@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+import os
 import time
 import paddle
 import paddle.fluid as fluid
@@ -19,17 +19,17 @@ import paddle.distributed.fleet as fleet
 
 
 class Trainer(object):
-    def __init__(self, place):
-        self.place = place
+    def __init__(self):
+        self.place = None
 
 
 class CPUTrainer(Trainer):
-    def __init__(self, place):
-        super(CPUTrainer, self).__init__(place)
-
+    def __init__(self):
+        super(CPUTrainer, self).__init__()
 
     def fit(self, model, dataloader, epoch, start_step=10):
         fleet.init_worker()
+        self.place = fluid.CPUPlace()
         exe = fluid.Executor(self.place)
         exe.run(fluid.default_startup_program())
 
@@ -52,16 +52,16 @@ class CPUTrainer(Trainer):
                            1 / (end_time - start_time)))
                 step += 1
 
-        fleet.stop_worker() 
+        fleet.stop_worker()
 
 
 class MultiGPUTrainer(Trainer):
-    def __init__(self, place):
-        super(MultiGPUTrainer, self).__init__(place)
-        print(self.place)
+    def __init__(self):
+        super(MultiGPUTrainer, self).__init__()
 
     def fit(self, model, dataloader, epoch, use_dali=False, start_step=10):
-        
+        self.place = fluid.CUDAPlace(
+            int(os.environ.get('FLAGS_selected_gpus', 0)))
         exe = fluid.Executor(self.place)
         exe.run(fluid.default_startup_program())
 
