@@ -12,4 +12,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from lr_strategy import *
+from .lr_strategy import *
